@@ -87,6 +87,7 @@ static char rcsid[] = "$TOG: Label.c /main/26 1997/06/18 17:40:00 samborn $"
 #include <Xm/XpmP.h>
 #include <string.h>
 
+#define FIX_1442
 
 #define Pix(w)			((w)->label.pixmap)
 #define Pix_insen(w)		((w)->label.pixmap_insen)
@@ -2666,10 +2667,10 @@ _XmLabelConvert(Widget w,
       Atom *targs;
 
       if (cs->target == atoms[XmATARGETS]) {
-	targs = XmeStandardTargets(w, 6, &target_count);
+	targs = XmeStandardTargets(w, 7, &target_count);
       } else {
 	target_count = 0;
-	targs = (Atom *) XtMalloc(sizeof(Atom) * 6);
+	targs = (Atom *) XtMalloc(sizeof(Atom) * 7);
       }
       
       value = (XtPointer) targs;
@@ -2932,7 +2933,11 @@ ConvertToEncoding(Widget w, char* str, Atom encoding,
     /* Fix for Bug 1117 - if str is null then a SEGVIOLATION occures
      * in strlen.
      */
+#ifdef FIX_1442
+    *length = str ? strlen(str) : 0;
+#else
     *length = str ? strlen(rval) : 0;
+#endif
 
     rval = _XmTextToLocaleText(w, (XtPointer) str,
 			       COMPOUND_TEXT, 8, 
