@@ -2190,12 +2190,7 @@ MultiActivate(
   if (pb->pushbutton.multiClick == XmMULTICLICK_KEEP)
     {
       if ((buttonEvent->xbutton.time - pb->pushbutton.armTimeStamp) >
-#ifdef XSETTINS_ON
-		XmeGetMultiClickTime(XtDisplay(pb)))
-#else 
 	  XtGetMultiClickTime(XtDisplay(pb)))
-#endif
-
 	pb->pushbutton.click_count = 1;
       else
         pb->pushbutton.click_count++;
@@ -2371,7 +2366,9 @@ ArmAndActivate(
   /* if the parent is menu system able, notify it about the select */
   if (menuSTrait != NULL)
     menuSTrait->entryCallback(XtParent(pb), (Widget)pb, &call_value);
-  
+#ifdef FIX_1375
+	pb->label.pixmap = pb->pushbutton.unarm_pixmap;
+#endif 
   if ((! pb->label.skipCallback) && (pb->pushbutton.activate_callback))
     {
       XFlush (XtDisplay (pb));
