@@ -82,6 +82,7 @@ static char rcsid[] = "$TOG: VendorS.c /main/21 1999/08/09 10:49:41 mgreess $"
 #include "XmImI.h"
 #include "VendorSI.h"
 #include "EditresComI.h"
+#include "XmI.h"
 
 #ifndef NO_MESSAGE_CATALOG
 #if !defined(NL_CAT_LOCALE)
@@ -2932,6 +2933,11 @@ Destroy(
 	 }
 	 XtFree((char *) ext);
     }    
+    
+#ifdef FIX_1388
+    if (XmeTraitGet((XtPointer) wid, XmQTtoolTipConfig) != NULL)
+            XmeTraitSet((XtPointer) wid, XmQTtoolTipConfig, (XtPointer) NULL);
+#endif    
 
     /*
      * If all VendorShells have been destroyed, destroy the XmDisplay object
