@@ -98,6 +98,7 @@ extern "C" { /* some 'locale.h' do not have prototypes (sun) */
    ((unsigned int)(unsigned long)(tablist) != XmAS_IS))
 
 #define  FIX_1414
+#define  FIX_1444
 /**********************************************************************
  *	      IMPORTANT NOTE: IMPLEMENTATION OF SHARING
  *
@@ -1979,6 +1980,7 @@ ValidateTag(XmRendition rend,
 }
 
 #ifdef FIX_1414
+#ifdef USE_XFT
 static int
 GetSameRenditions(XmRendition *rend_cache, XmRendition rend, int count_rend)
 {
@@ -2009,6 +2011,7 @@ GetSameRenditions(XmRendition *rend_cache, XmRendition rend, int count_rend)
 
 }
 #endif
+#endif
 
 /* Make sure all the font related resources make sense together and */
 /* then load the font specified by fontName if necessary. */
@@ -2900,9 +2903,17 @@ _XmXftDrawCreate(Display *display, Window window)
 			return _XmXftDrawCache[i].draw;
 		}
 	}
-        oldErrorHandler = XSetErrorHandler (_XmXftErrorHandler);
+
+#ifdef FIX_1444
+	if (!(draw = XftDrawCreate(display, window,
+	    DefaultVisual(display, DefaultScreen(display)),
+	    DefaultColormap(display, DefaultScreen(display))))) 
+            	draw = XftDrawCreateBitmap(display, window);
+#else
+	oldErrorHandler = XSetErrorHandler (_XmXftErrorHandler);	
 	xft_error = 0;
 	XGetWindowAttributes(display, window, &wa);
+	XSetErrorHandler(oldErrorHandler);
 	if (xft_error != BadWindow) {
 	    draw = XftDrawCreate(display, window,
 	        DefaultVisual(display, DefaultScreen(display)),
@@ -2910,7 +2921,7 @@ _XmXftDrawCreate(Display *display, Window window)
 	} else {
             draw = XftDrawCreateBitmap(display, window);
         }
-
+#endif
 	/* Store it in the cache. Look for an empty slot first */
 	for (i=0; i<_XmXftDrawCacheSize; i++)
 		if (_XmXftDrawCache[i].display == NULL) {
