@@ -1,17 +1,22 @@
 #ifndef lint
-static char const 
-yyrcsid[] = "$FreeBSD: src/usr.bin/yacc/skeleton.c,v 1.28 2000/01/17 02:04:06 bde Exp $";
+static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
 #endif
+
 #include <stdlib.h>
+
 #define YYBYACC 1
 #define YYMAJOR 1
 #define YYMINOR 9
-#define YYLEX yylex()
-#define YYEMPTY -1
-#define yyclearin (yychar=(YYEMPTY))
-#define yyerrok (yyerrflag=0)
-#define YYRECOVERING() (yyerrflag!=0)
-static int yygrowstack();
+#define YYPATCH 20050813
+
+#define YYEMPTY (-1)
+#define yyclearin    (yychar = YYEMPTY)
+#define yyerrok      (yyerrflag = 0)
+#define YYRECOVERING (yyerrflag != 0)
+
+extern int yyparse(void);
+
+static int yygrowstack(void);
 #define YYPREFIX "yy"
 #line 48 "wmlparse.y"
 
@@ -36,8 +41,7 @@ static int yygrowstack();
 #undef NULL
 #endif
 
-#line 40 "wmlparse.c"
-#define YYERRCODE 256
+#line 45 "wmlparse.c"
 #define CLASS 1
 #define RESOURCE 2
 #define DATATYPE 3
@@ -90,7 +94,8 @@ static int yygrowstack();
 #define RBRACE 47
 #define STRING 48
 #define ERRORTOKEN 49
-const short yylhs[] = {                                        -1,
+#define YYERRCODE 256
+short yylhs[] = {                                        -1,
     0,    0,    1,    1,    1,    1,    1,    1,    1,    1,
    10,    1,    2,   11,   11,   13,   11,    3,   14,   14,
    16,   14,    4,   17,   17,   19,   17,    5,   20,   20,
@@ -118,7 +123,7 @@ const short yylhs[] = {                                        -1,
   128,  133,  128,  134,  128,  129,  129,  129,  131,  131,
   131,  132,  132,  132,  132,  132,   35,
 };
-const short yylen[] = {                                         2,
+short yylen[] = {                                         2,
     0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
     0,    3,    2,    2,    3,    0,    3,    2,    2,    3,
     0,    3,    2,    2,    3,    0,    3,    2,    2,    3,
@@ -146,7 +151,7 @@ const short yylen[] = {                                         2,
     5,    0,    5,    0,    3,    1,    1,    1,    1,    1,
     1,    1,    1,    1,    1,    1,    1,
 };
-const short yydefred[] = {                                      1,
+short yydefred[] = {                                      1,
     0,   11,    0,    0,    0,    0,    0,    0,    0,    0,
     2,    3,    4,    5,    6,    7,    8,    9,   10,    0,
    16,  257,    0,    0,    0,   21,    0,    0,    0,   31,
@@ -187,7 +192,7 @@ const short yydefred[] = {                                      1,
   122,  101,    0,   99,  103,    0,    0,  128,  109,  104,
   106,    0,    0,  105,  107,
 };
-const short yydgoto[] = {                                       1,
+short yydgoto[] = {                                       1,
    11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
    23,   24,   55,   27,   28,   59,   51,   52,   83,   31,
    32,   63,   35,   36,   67,   39,   40,   71,   43,   44,
@@ -203,7 +208,7 @@ const short yydgoto[] = {                                       1,
   184,  321,  242,  121,   82,  155,  146,  156,  157,  289,
   158,  253,  290,  186,
 };
-const short yysindex[] = {                                      0,
+short yysindex[] = {                                      0,
   116,    0,  -22,  -16,   12,   53,   65,   81,   87,   93,
     0,    0,    0,    0,    0,    0,    0,    0,    0,  -11,
     0,    0,  -20,    2,  100,    0,  -20,  108,  110,    0,
@@ -244,7 +249,7 @@ const short yysindex[] = {                                      0,
     0,    0,  325,    0,    0,  328,  171,    0,    0,    0,
     0,  327,  333,    0,    0,
 };
-const short yyrindex[] = {                                      0,
+short yyrindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    7,    0,    0,    0,   15,    0,    0,    0,
@@ -285,7 +290,7 @@ const short yyrindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,    0,    0,    0,
 };
-const short yygindex[] = {                                      0,
+short yygindex[] = {                                      0,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,  372,    0,    0,  264,    0,    0,  346,    0,    0,
   262,    0,    0,  293,    0,    0,  357,    0,    0,  251,
@@ -302,7 +307,7 @@ const short yygindex[] = {                                      0,
     0,    0,    0,    0,
 };
 #define YYTABLESIZE 473
-const short yytable[] = {                                      29,
+short yytable[] = {                                      29,
    33,   37,   41,   45,   49,   53,   13,   13,   13,   13,
    13,   13,   13,   13,   18,   18,   18,   18,   18,   18,
    18,   18,   29,  180,  360,   22,   33,   22,  103,  361,
@@ -352,7 +357,7 @@ const short yytable[] = {                                      29,
     0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     0,    0,  147,
 };
-const short yycheck[] = {                                       4,
+short yycheck[] = {                                       4,
     5,    6,    7,    8,    9,   10,    0,    1,    2,    3,
     4,    5,    6,    7,    0,    1,    2,    3,    4,    5,
     6,    7,   27,   23,   11,   48,   31,   48,   46,   16,
@@ -408,7 +413,7 @@ const short yycheck[] = {                                       4,
 #endif
 #define YYMAXTOKEN 52
 #if YYDEBUG
-const char * const yyname[] = {
+char *yyname[] = {
 "end-of-file","CLASS","RESOURCE","DATATYPE","CONTROLLIST","ENUMERATIONSET",
 "ENUMERATIONVALUE","CHARACTERSET","DOCNAME","CONVFUNC","ALIAS","TYPE",
 "RESOURCELITERAL","RELATED","INTERNALLITERAL","XRMRESOURCE","EXCLUDE",
@@ -419,7 +424,7 @@ const char * const yyname[] = {
 "RIGHTTOLEFT","ONEBYTE","TWOBYTE","MIXED1_2BYTE","COLON","SEMICOLON","EQUALS",
 "LBRACE","RBRACE","STRING","ERRORTOKEN","CHILD","CHILDREN","PARENTCLASS",
 };
-const char * const yyrule[] = {
+char *yyrule[] = {
 "$accept : statement_block_list",
 "statement_block_list :",
 "statement_block_list : statement_block_list statement_block",
@@ -686,30 +691,36 @@ typedef int YYSTYPE;
 #if YYDEBUG
 #include <stdio.h>
 #endif
+
+/* define the initial stack-sizes */
 #ifdef YYSTACKSIZE
 #undef YYMAXDEPTH
-#define YYMAXDEPTH YYSTACKSIZE
+#define YYMAXDEPTH  YYSTACKSIZE
 #else
 #ifdef YYMAXDEPTH
 #define YYSTACKSIZE YYMAXDEPTH
 #else
-#define YYSTACKSIZE 10000
-#define YYMAXDEPTH 10000
+#define YYSTACKSIZE 500
+#define YYMAXDEPTH  500
 #endif
 #endif
-#define YYINITSTACKSIZE 200
-int yydebug;
-int yynerrs;
-int yyerrflag;
-int yychar;
-short *yyssp;
+
+#define YYINITSTACKSIZE 500
+
+int      yydebug;
+int      yynerrs;
+int      yyerrflag;
+int      yychar;
+short   *yyssp;
 YYSTYPE *yyvsp;
-YYSTYPE yyval;
-YYSTYPE yylval;
-short *yyss;
-short *yysslim;
-YYSTYPE *yyvs;
-int yystacksize;
+YYSTYPE  yyval;
+YYSTYPE  yylval;
+
+/* variables for the parser stack */
+static short   *yyss;
+static short   *yysslim;
+static YYSTYPE *yyvs;
+static int      yystacksize;
 #line 748 "wmlparse.y"
 
 /*
@@ -724,9 +735,9 @@ char *s;
 
 #include "wmllex.c"
 
-#line 728 "wmlparse.c"
+#line 739 "wmlparse.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
-static int yygrowstack()
+static int yygrowstack(void)
 {
     int newsize, i;
     short *newss;
@@ -738,17 +749,22 @@ static int yygrowstack()
         return -1;
     else if ((newsize *= 2) > YYMAXDEPTH)
         newsize = YYMAXDEPTH;
+
     i = yyssp - yyss;
-    newss = yyss ? (short *)realloc(yyss, newsize * sizeof *newss) :
-      (short *)malloc(newsize * sizeof *newss);
-    if (newss == NULL)
+    newss = (yyss != 0)
+          ? (short *)realloc(yyss, newsize * sizeof(*newss))
+          : (short *)malloc(newsize * sizeof(*newss));
+    if (newss == 0)
         return -1;
-    yyss = newss;
+
+    yyss  = newss;
     yyssp = newss + i;
-    newvs = yyvs ? (YYSTYPE *)realloc(yyvs, newsize * sizeof *newvs) :
-      (YYSTYPE *)malloc(newsize * sizeof *newvs);
-    if (newvs == NULL)
+    newvs = (yyvs != 0)
+          ? (YYSTYPE *)realloc(yyvs, newsize * sizeof(*newvs))
+          : (YYSTYPE *)malloc(newsize * sizeof(*newvs));
+    if (newvs == 0)
         return -1;
+
     yyvs = newvs;
     yyvsp = newvs + i;
     yystacksize = newsize;
@@ -760,37 +776,14 @@ static int yygrowstack()
 #define YYREJECT goto yyabort
 #define YYACCEPT goto yyaccept
 #define YYERROR goto yyerrlab
-
-#ifndef YYPARSE_PARAM
-#if defined(__cplusplus) || __STDC__
-#define YYPARSE_PARAM_ARG void
-#define YYPARSE_PARAM_DECL
-#else	/* ! ANSI-C/C++ */
-#define YYPARSE_PARAM_ARG
-#define YYPARSE_PARAM_DECL
-#endif	/* ANSI-C/C++ */
-#else	/* YYPARSE_PARAM */
-#ifndef YYPARSE_PARAM_TYPE
-#define YYPARSE_PARAM_TYPE void *
-#endif
-#if defined(__cplusplus) || __STDC__
-#define YYPARSE_PARAM_ARG YYPARSE_PARAM_TYPE YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL
-#else	/* ! ANSI-C/C++ */
-#define YYPARSE_PARAM_ARG YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL YYPARSE_PARAM_TYPE YYPARSE_PARAM;
-#endif	/* ANSI-C/C++ */
-#endif	/* ! YYPARSE_PARAM */
-
 int
-yyparse (YYPARSE_PARAM_ARG)
-    YYPARSE_PARAM_DECL
+yyparse(void)
 {
     register int yym, yyn, yystate;
 #if YYDEBUG
     register const char *yys;
 
-    if ((yys = getenv("YYDEBUG")))
+    if ((yys = getenv("YYDEBUG")) != 0)
     {
         yyn = *yys;
         if (yyn >= '0' && yyn <= '9')
@@ -800,7 +793,7 @@ yyparse (YYPARSE_PARAM_ARG)
 
     yynerrs = 0;
     yyerrflag = 0;
-    yychar = (-1);
+    yychar = YYEMPTY;
 
     if (yyss == NULL && yygrowstack()) goto yyoverflow;
     yyssp = yyss;
@@ -808,7 +801,7 @@ yyparse (YYPARSE_PARAM_ARG)
     *yyssp = yystate = 0;
 
 yyloop:
-    if ((yyn = yydefred[yystate])) goto yyreduce;
+    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
     if (yychar < 0)
     {
         if ((yychar = yylex()) < 0) yychar = 0;
@@ -837,7 +830,7 @@ yyloop:
         }
         *++yyssp = yystate = yytable[yyn];
         *++yyvsp = yylval;
-        yychar = (-1);
+        yychar = YYEMPTY;
         if (yyerrflag > 0)  --yyerrflag;
         goto yyloop;
     }
@@ -848,16 +841,16 @@ yyloop:
         goto yyreduce;
     }
     if (yyerrflag) goto yyinrecovery;
-#if defined(lint) || defined(__GNUC__)
-    goto yynewerror;
-#endif
-yynewerror:
+
     yyerror("syntax error");
-#if defined(lint) || defined(__GNUC__)
+
+#ifdef lint
     goto yyerrlab;
 #endif
+
 yyerrlab:
     ++yynerrs;
+
 yyinrecovery:
     if (yyerrflag < 3)
     {
@@ -906,9 +899,10 @@ yyinrecovery:
                     YYPREFIX, yystate, yychar, yys);
         }
 #endif
-        yychar = (-1);
+        yychar = YYEMPTY;
         goto yyloop;
     }
+
 yyreduce:
 #if YYDEBUG
     if (yydebug)
@@ -1327,7 +1321,7 @@ case 257:
 #line 744 "wmlparse.y"
 { strcpy (yynameval, (XmConst char *)yystringval); }
 break;
-#line 1331 "wmlparse.c"
+#line 1325 "wmlparse.c"
     }
     yyssp -= yym;
     yystate = *yyssp;
@@ -1377,10 +1371,13 @@ to state %d\n", YYPREFIX, *yyssp, yystate);
     *++yyssp = yystate;
     *++yyvsp = yyval;
     goto yyloop;
+
 yyoverflow:
     yyerror("yacc stack overflow");
+
 yyabort:
     return (1);
+
 yyaccept:
     return (0);
 }
